;; Generated package description from selected-window-contrast.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "selected-window-contrast" "0.4.1.0.20260331.215551" "Highlight window and cursor at switching" '((emacs "26.1")) :commit "6b2c1aab2394d707c799b658ee2dbda5f4140d66" :authors '(("Anoncheg" . "vitalij@gmx.com")) :maintainer '("Anoncheg" . "vitalij@gmx.com") :keywords '("color" "windows" "faces" "buffer" "background") :url "https://codeberg.org/Anoncheg/selected-window-contrast")
